#    5-a-day - utilities to participate in 5-A-Day statistics
#    Copyright (C) 2008  Canonical Ltd.
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

from gettext import gettext as _
import getopt
import glob
import os
import sys

# error codes
COMMAND_LINE_SYNTAX_ERROR = 2


def usage():
    print _("""5-a-day --update                   update ~/.signature with the bugs you've worked on
    --html                         update ~/.signature and print HTML signature
    --yesterday                    update ~/.signature with yesterdays bugs

Instructions:
 - join https://launchpad.net/~5-a-day-participants
 - run  bzr launchpad-login <your Launchpad ID>""")
    if glob.glob(os.path.expanduser("~")+"/.5-a-day*"):
        print _(" - it's safe to remove all ~/.5-a-day*""")


def parse_args():
    program_name = os.path.basename(sys.argv[0])

    if program_name == '5-a-day' and len(sys.argv) == 1:
        # You have to specify at least one parameter
        usage()
        sys.exit(COMMAND_LINE_SYNTAX_ERROR)

    try:
        long_opts = [
            "help",
            "update",
            "html",
            "yesterday"
        ]
        opts, args = getopt.gnu_getopt(sys.argv[1:], "afhuv", long_opts)
    except getopt.GetoptError, e:
        # print help information and exit:
        print str(e) # will print something like "option -a not recognized"
        usage()
        sys.exit(COMMAND_LINE_SYNTAX_ERROR)

    commands = set()
    flags = {
        "html": False,
        "yesterday": False,
    }

    for o, a in opts:
        if o in ("-h", "--help"):
            usage()
            sys.exit(0)
        elif o in ("--html"):
            flags["html"] = True
        elif o in ("-u", "--update"):
            flags["update"] = True
        elif o in ("--yesterday"):
            flags["yesterday"] = True
        else:
            assert False, _("unhandled option")

    if program_name == 'update-signatures':
        flags["update"] = True

    if len(commands) == 1 and len(args) == 0:
        print _("E: You have to specify at least one argument.")
        sys.exit(COMMAND_LINE_SYNTAX_ERROR)

    return commands, flags, args
